summaryrefslogtreecommitdiffstats
path: root/extensions/shell/common
diff options
context:
space:
mode:
authorarurajku <arurajku@cisco.com>2014-12-16 07:52:17 -0800
committerCommit bot <commit-bot@chromium.org>2014-12-16 15:52:50 +0000
commitfddf2473ddeedafe13558f247fa57e04c782545c (patch)
tree929418f5b4ba405d720407dbd366bf2b35c2cb02 /extensions/shell/common
parenta068d750508468f0d5de2da69a150e76be45e634 (diff)
downloadchromium_src-fddf2473ddeedafe13558f247fa57e04c782545c.zip
chromium_src-fddf2473ddeedafe13558f247fa57e04c782545c.tar.gz
chromium_src-fddf2473ddeedafe13558f247fa57e04c782545c.tar.bz2
Rename --app-shell-host-window-bounds commandline switch to --app-shell-host-window-size.
The keyword "bounds" doesn't make sense because this switch is used to change only the size of the host window. Similar CL had landed[1] for content_shell with --content-shell-host-window-size as a switch name. [1] https://codereview.chromium.org/783203002/ Review URL: https://codereview.chromium.org/805203002 Cr-Commit-Position: refs/heads/master@{#308592}
Diffstat (limited to 'extensions/shell/common')
-rw-r--r--extensions/shell/common/switches.cc4
-rw-r--r--extensions/shell/common/switches.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/extensions/shell/common/switches.h b/extensions/shell/common/switches.h
index 61656f52..7fe3d59 100644
--- a/extensions/shell/common/switches.h
+++ b/extensions/shell/common/switches.h
@@ -10,7 +10,7 @@ namespace switches {
// All switches in alphabetical order. The switches should be documented
// alongside the definition of their values in the .cc file.
-extern const char kAppShellHostWindowBounds[];
+extern const char kAppShellHostWindowSize[];
extern const char kAppShellInstallCrx[];
extern const char kAppShellPreferredNetwork[];
extern const char kAppShellRefreshToken[];
diff --git a/extensions/shell/common/switches.cc b/extensions/shell/common/switches.cc
index 303628aef..446b424 100644
--- a/extensions/shell/common/switches.cc
+++ b/extensions/shell/common/switches.cc
@@ -7,8 +7,8 @@
namespace extensions {
namespace switches {
-// Bounds for the host window to create (i.e. "800x600").
-const char kAppShellHostWindowBounds[] = "app-shell-host-window-bounds";
+// Size for the host window to create (i.e. "800x600").
+const char kAppShellHostWindowSize[] = "app-shell-host-window-size";
// ID of an extension CRX to be downloaded from the web store.
const char kAppShellInstallCrx[] = "app-shell-install-crx";